@@ -25,5 +25,7 @@ export default {
   FILE_UPLOAD_SUCCESS: 'FILE_UPLOAD_SUCCESS',
   FILE_UPLOAD_ERROR: 'FILE_UPLOAD_ERROR',
   START_FILE_UPLOAD: 'START_FILE_UPLOAD',
-  SET_FILE_UPLOAD_PERCENTAGE: 'SET_FILE_UPLOAD_PERCENTAGE'
+  SET_FILE_UPLOAD_PERCENTAGE: 'SET_FILE_UPLOAD_PERCENTAGE',
+  SAVING_DOCUMENT: 'SAVING_DOCUMENT',
+  SAVING_DOCUMENT_COMPLETED: 'SAVING_DOCUMENT_COMPLETED',
 };
